==> xlr-ansible-automation-controller-integration-23.3.0.jar: ansiblecontroller/LaunchWaitSchedule.py <==
#
# Copyright (c) 2020. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of XebiaLabs, Inc. and its affiliates, subsidiaries, and licensors.
#
import json
from xlrelease.HttpRequest import HttpRequest
import time
import sys
from ansiblecontroller import AAPServer

ansible_instance = AAPServer(ansibletower,username,password,apiToken)
request = ansible_instance.create_request()
headers = ansible_instance.create_header(request)

retryCounter = {
    "currentPollingTrial": 0
}

api_url = '/api/v2/jobs/%s/' % job_id

if max_retries:
    if retryCounter['currentPollingTrial'] < int(max_retries):
        # Define the URL for the Ansible Tower API endpoint to launch a job.
        response = request.get(api_url, contentType='application/json',headers=headers)
        if response.isSuccessful():
            result = json.loads(response.response)
            status=result['status']
            print("Job status is "+ status)
            if status not in ["running","pending","waiting"]:
              if stopOnFailure and not status == 'successful':
                raise Exception("Job status is "+ status)
              else:
                # task completed
                print("```")
                print(">>> Task completed after " + str(retryCounter['currentPollingTrial']) + " tries with status "+ status)
                print("```")
                print("\n")
                print("```")  # started markdown code block
                job_output=request.get(api_url+'stdout/', contentType='text/plain',headers=headers).response
                print(job_output)
                print("```")
                print("\n")  # end markdown code block
                print("* [>>> Job %s Link](%s/#/jobs/%s) <<<" % (str(job_id), ansibletower['url'], str(job_id)))
                print("\n")
                result= job_output
            else:
                retryCounter['currentPollingTrial']+=1
                task.schedule("ansiblecontroller/LaunchWaitSchedule.py",int(wait_interval))
        else:
            raise Exception("Failed !. Server return [%s], with content [%s]" % (response.status, response.response))

    if retryCounter['currentPollingTrial'] == int(max_retries):
        # maximum number of tries reached, handle the error
        raise Exception("Error: maximum number of tries reached")

==> xlr-ansible-automation-controller-integration-24.3.13-1116.130.jar: ansiblecontroller/LaunchWaitSchedule.py <==
#
# Copyright (c) 2020. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of XebiaLabs, Inc. and its affiliates, subsidiaries, and licensors.
#
import json
from xlrelease.HttpRequest import HttpRequest
from ansiblecontroller import AAPServer

ansible_instance = AAPServer(ansibletower,username,password,apiToken)
request = ansible_instance.create_request()
headers = ansible_instance.create_header()

retryCounter = {
    "currentPollingTrial": 0
}

api_url = '/api/controller/v2/jobs/%s/' % job_id

if max_retries:
    if retryCounter['currentPollingTrial'] < int(max_retries):
        # Define the URL for the Ansible Tower API endpoint to launch a job.
        response = request.get(api_url, contentType='application/json',headers=headers)
        if response.isSuccessful():
            result = json.loads(response.response)
            status=result['status']
            if status not in ["running","pending","waiting"]:
              if stopOnFailure and not status == 'successful':
                raise Exception("Job status is "+ status)
              else:
                # task completed
                print("[Job : %s](%s/execution/jobs/playbook/%s/output)" % (str(job_id), str(ansibletower['url']).rstrip('/'), str(job_id)))
                response = request.get(api_url+'stdout/', contentType='text/plain',headers=headers)
                if response.isSuccessful():
                    job_output=response.response
                    result= job_output
                else:
                    raise Exception("Failed to get job output. Server return [%s], with content [%s]" % (response.status, response.response))
            else:
                retryCounter['currentPollingTrial']+=1
                task.schedule("ansiblecontroller/LaunchWaitSchedule.py",int(wait_interval))
        else:
            raise Exception("Failed to get job status. Server return [%s], with content [%s]" % (response.status, response.response))

    if retryCounter['currentPollingTrial'] == int(max_retries):
        # maximum number of tries reached, handle the error
        raise Exception("Error: maximum number of tries reached")
